* Flower-Insect Attitude

* Generic IAT syntax for SPSS .
* This computed "D_biep", which stands for "D measure with built-in error
*   penalty", as described in:
* Greenwald, A. G, Nosek, B. A., & Banaji, M. R. (2003).  Understanding and using 
*  the Implicit Association Test: I. An improved scoring algorithm.  Journal of 
*  Personality and Social Psychology, 85, 197-216.

*D_biep is the preferred IAT measure when the IAT procedure allows subjects to correct
* errors *AND* records latency to the occurrence of the eventual correct response. 
* This is the procedure used in the Generic IAT available on my web site, at:
*  http://faculty.washington.edu/agg (follow link to IAT MATERIALS). 

*To compute D measure with fixed 600 ms error penalty or the 2-standard deviation
*  error penalty, locate the syntax files with appropriate names indicating their .
*  purpose to make those computations (on AGGs web site) .

*D_biep will be scored so that higher numbers indicate stronger association
*  of Pleasant with INSECT, unless the scoring is reversed
*  (see instructions for reversal about over halfway down through this syntax).

*TO CONVERT THIS FILE TO AN .sps SYNTAX FILE, FOLLOW THE INSTRUCTIONS TO BE FOUND
*  AT THE BOTTOM OF THIS FILE.
******************************************************************************.

***************************************************************************** .
** REPLACEMENT OF THE FILENAME IN QUOTES IN THE NEXT LINE WITH THE ACTUAL  ** .
** .dat FILENAME MAY BE THE ONLY MANUALLY-MADE CHANGE NEEDED IN THIS FILE. ** .
** MAKE THIS CHANGE AFTER YOU HAVE SAVED THE .sps FILE ACCORDING TO THE    ** .
** INSTRUCTIONS AT THE BOTTOM OF THIS .doc FILE.                           ** .
***************************************************************************** .
GET TRANSLATE FILE = 'Flower-Insect Attitude.dat'
  /TYPE=TAB /MAP /FIELDNAMES .

VALUE LABELS blocknum
 1 'Target categories practice'
 2 'Pleasant-Unpleasant practice'
 3 'First pairing practice'
 4 'First pairing test'
 5 'Reversed target categories pract'
 6 'Second pairing practice'
 7 'Second pairing test' .

IF (MOD(subject,2) = 1) ORDER = 1 .
IF (MOD(subject,2) = 1) ORDER = 1 .
IF (MOD(subject,2) = 0) ORDER = 2 .
IF (MOD(subject,2) = 0) ORDER = 2 .


COMPUTE pairing = 0.
IF ((order=1) and (blocknum=3|blocknum=4)) pairing = 1.
IF ((order=1) and (blocknum=6|blocknum=7)) pairing = 2.
IF ((order=2) and (blocknum=6|blocknum=7)) pairing = 1.
IF ((order=2) and (blocknum=3|blocknum=4)) pairing = 2.

COMPUTE test = 0.
IF (blocknum=3|blocknum=6) test = 1.
IF (blocknum=4|blocknum=7) test = 2.

VALUE LABELS 
   test 0 'single-task practice' 1 '1st combined block' 2 '2nd combined block'
 / correct 0 'error' 1 'correct' .

VARIABLE LABELS 
   correct  "0=error, 1=correct"
 / blocknum "block number"
 / trialnum "trial number"
 / order "order of combined tasks"
 / pairing "paired categories"
 / test "1st or 2nd combined block" 
 / pairing "COMBINATION" .

* replace the labels below with ones meaningful for the targets and attributes used.
VALUE LABELS 
   pairing 
    0 'single task practice'
    1 'Pleasant+INSECT and Unpleasant+FLOWER'
    2 'Pleasant+FLOWER and Unpleasant+INSECT'
 / order 
    1 'Pleasant+INSECT and Unpleasant+FLOWER first'
    2 'Pleasant+FLOWER and Unpleasant+INSECT first' .

COMPUTE error = 100*(1 - correct).

*Save data to re-use for computing other measures .
* Unneeded variables can be dropped here, using keyword /DROP .
SAVE OUTFILE = 'temp.sav'  .

DESCRIPTIVES ALL . 

GET FILE = 'temp.sav' .
*Use data for Blocks 3,4,6, and 7 (i.e., TEST = 1 or 2) .
SELECT IF (TEST=1 OR TEST=2) .
*Drop dummy trials at beginning of blocks .
SELECT IF (trialnum gt 1).

*Mark trials with latency < 300 ms (for possible subject discard) .
COMPUTE FLAG_300 = 0 .
IF (LATENCY < 300) FLAG_300 = 1 .
*Mark trials with latency < 400 ms (to provide a count of these) .
COMPUTE FLAG_400 = 0 .
IF (LATENCY < 400) FLAG_400 = 1 .
*Mark trials with latency > 10000 ms (to provide a count of these) .
COMPUTE FLAG_10K = 0 .
IF (LATENCY GT 10000) FLAG_10K = 1 .

*Following line can be used to check frequencies of fast & slow responses & errors .
FREQUENCIES FLAG_300 FLAG_400 FLAG_10K ERROR .

*Record criteria for potential use in subject discards .
*This count can later be used as the basis for subject discard .
AGGREGATE OUTFILE = 'CRITERIA.SAV'
 / BREAK = SUBJECT ORDER
 / PCT_300 = PGT(FLAG_300,0) 
 / PCT_400 = PGT(FLAG_400,0)
 / PCT_10K = PGT(FLAG_10K,0)
 / AVELTNCY ERRORPCT = MEAN (LATENCY ERROR)
 / NTRIALS = N .

*Drop trials slower than 10000 ms for LATENCY .
SELECT IF (LATENCY LE 10000) .

******* OPTIONAL DELETION OF LATENCIES BELOW 400 ms  ********* .
* Remove the asterisk before following to delete trials with latencies below 400 ms . 
*SELECT IF (LATENCY GE 400) .
******* DELETE LATENCIES BELOW 400 ms  ********* .

* The following aggregate command computes block means and SDs needed for the D measures.
AGGREGATE OUTFILE = *
 / BREAK = SUBJECT BLOCKNUM ORDER PAIRING TEST
 / Mean_lat mn_error = MEAN(latency error) / SD_lat = SD(latency)
 / NTRIALS = N .

*Save this as a record of this stage of analysis .
SAVE OUTFILE = 'BIEP.ALL_MEANS&SDs.SAV' .

*Corrections made 29 Dec 07:  erroneous "Dnum1" changed to "M1", "Dnum2" to "M2".
IF (PAIRING = 1) N1 = NTRIALS .
IF (PAIRING = 2) N2 = NTRIALS .
IF (PAIRING = 1) M1 = Mean_lat .
IF (PAIRING = 2) M2 = Mean_lat .
IF (PAIRING = 1) ERR1 = Mn_error .
IF (PAIRING = 2) ERR2 = Mn_error .
IF (PAIRING = 1) SD1 = SD_lat .
IF (PAIRING = 2) SD2 = SD_lat .

AGGREGATE OUTFILE = *
 / BREAK = SUBJECT ORDER TEST 
 / M1 M2 ERR1 ERR2 N1 N2 SD1 SD2 =
  FIRST(M1 M2 ERR1 ERR2 N1 N2 SD1 SD2) .

*Save this as a record of this stage of analysis .
SAVE OUTFILE = 'BIEP.MEANS&SDS.SAV' .

IF(TEST=1) ERR1a = ERR1 .
IF(TEST=1) ERR2a = ERR2 .
IF(TEST=2) ERR1b = ERR1 .
IF(TEST=2) ERR2b = ERR2 .

* These are the numerator copmponents in millisecond units.
IF(TEST=1) M1a = M1 .
IF(TEST=1) M2a = M2 .
IF(TEST=2) M1b = M1 .
IF(TEST=2) M2b = M2 .

IF(TEST=1) SD1a = SD1 .
IF(TEST=1) SD2a = SD2 .
IF(TEST=2) SD1b = SD1 .
IF(TEST=2) SD2b = SD2 .

IF(TEST=1) N1a = N1 .
IF(TEST=1) N2a = N2 .
IF(TEST=2) N1b = N1 .
IF(TEST=2) N2b = N2 .

COMPUTE D_asis_num = M2 - M1 .

*Use SD based on all responses (StanDevX) as denominator for D_biep .
COMPUTE D_asis_denom = SQRT( ( ((N1-1) * SD1**2 + (N2-1) * SD2**2)
                   + ((N1+N2) * ((M1-M2)**2) / 4) ) / (N1 + N2 - 1) ) .

IF (TEST=1) D_BIEP_a = D_asis_num / D_asis_denom .
IF (TEST=2) D_BIEP_b = D_asis_num / D_asis_denom .
IF (TEST=1) Na = N1+N2 .
IF (TEST=2) Nb = N1+N2 .

AGGREGATE OUTFILE = *
 / BREAK = SUBJECT ORDER
 / D_biep_a D_biep_b M1a M2a M1b M2b ERR1a ERR2a ERR1b ERR2b Na Nb = 
   FIRST(D_biep_a D_biep_b M1a M2a M1b M2b ERR1a ERR2a ERR1b ERR2b Na Nb).

VARIABLE LABELS
   D_biep_a 'Pleasant+INSECT association 1st blocka'
 / D_biep_b 'Pleasant+INSECT association 2nd blocka' 
 / Na '# trials, 1st combined blocks'
 / Nb '# trials, 2nd combined blocks'
 / M1a 'Mn Lat. 1st block, pairing 1'
 / M2a 'Mn Lat. 1st block, pairing 2' 
 / M1b 'Mn Lat. 2nd block, pairing 1' 
 / M2b 'Mn Lat. 2nd block, pairing 2' 
 / ERR1a 'Error % 1st block, pairing 1'
 / ERR2a 'Error % 1st block, pairing 2' 
 / ERR1b 'Error % 2nd block, pairing 1' 
 / ERR2b 'Error % 2ns block, pairing 2' 
 / SUBJECT 'Session ID' .

COMPUTE ERR_1 = (ERR1a + ERR1b) / 2 .
COMPUTE ERR_2 = (ERR2a + ERR2b) / 2 .
 
VARIABLE LABELS
   ERR_1 'Error % for Pairing 1 (both combined tasks)'
 / ERR_2 'Error % for Pairing 2 (both combined tasks)' .

*Compute unweighted combination of measures based on first and second blocks
  of combined tasks.
* !! Do this even if there are fewer trials in the first block because the 
*  first block has been found to have as good or better validity, even with 
*  fewer trials (see Greenwald, Nosek, & Banaji, JPSP 2003) .

COMPUTE D_biep = (D_biep_a + D_biep_b) / 2 .
VARIABLE LABELS
   D_biep   'Pleasant+INSECT association all blocks' .


*************************************************************
** TO REVERSE THE SCORING OF THE IAT, REMOVE THE ASTERISKS **
** FROM THE NEXT FOUR COMMAND LINES.                       **
************************************************************* .

* COMPUTE D_biep = 0 - D_biep .
* COMPUTE D_biep_a = 0 - D_biep_a .
* COMPUTE D_biep_b = 0 - D_biep_b .
* VARIABLE LABELS
    D_biep   'Pleasant+FLOWER association all blocks' 
  / D_biep_a 'Pleasant+FLOWER association 1st blocka'
  / D_biep_b 'Pleasant+FLOWER association 2nd blocka' .

FORMAT D_biep D_BIEP_a D_BIEP_b D_BIEP (F6.3) SUBJECT (F7.0) 
    Na Nb (F4.0) M1a M2a M1b M2b (F7.1)
    ERR1a ERR2a ERR1b ERR2b ERR_1 ERR_2 (F5.1) .

SAVE OUTFILE = 'D_BIEP_temp.SAV' .
DESCRIPTIVES ALL .

**************************************************************.
**** STEP 3: COMBINE MEASURES AND SAVE ****.
**************************************************************.

*Add labels to CRITERIA.SAV .
GET FILE = 'CRITERIA.SAV' .
VARIABLE LABELS
   PCT_300 '% latencies below 300 ms'
 / PCT_400 '% latencies below 400 ms'
 / PCT_10K '% latencies above 10,000 ms'
 / AVELTNCY 'Overall average latency (ms)'
 / ERRORPCT 'Overall % errors' 
 / NTRIALS 'Total # of combined-task trials' .

FORMAT AVELTNCY (F7.1) PCT_300 PCT_400 PCT_10K ERRORPCT (F6.1) SUBJECT (F7.0) .

SAVE OUTFILE = 'CRITERIA.SAV' .

*Combine and save .
MATCH FILES FILE = 'D_BIEP_temp.SAV' / FILE = 'CRITERIA.SAV' /BY SUBJECT  .

SAVE OUTFILE = 'D_BIEP.SAV' .

*Note: No subjects have yet been discarded.  However, each record contains .
* three variables that might be used for discard .
* PCT_300 = overall % of responses with latencies below 300 ms .
* ERRORPCT = overall error % .
* AVELTNCY = overall average latency .
* [Note that 'aveltncy' was computed _BEFORE_ discard of latencies above 10000 ms].

GET FILE = 'D_BIEP.SAV' .
DESCRIPTIVES ALL .

*---------------------- .
* OPERATING INSTRUCTIONS:  CREAING THE .sps FILE .
*---------------------- .

*THESE INSTRUCTIONS ASSUME THAT YOU HAVE CREATED AN INQUISIT IAT PROGRAM (.exp 
*  FILE) USING THE WORD .doc FILE, "GenericIATsyntaxForm.26Nov05.doc".  THIS 
*  MERGE AND SAVE IS THAN CONDUCTED IN FASHION SIMILAR TO MERGING AND SAVING 
*  THE .exp FILE, USING THE SAME RECORD IN THE ASSOCIATED DATA SOURCE FILE 
*  ('GenericIATdata.doc') THAT WAS USED TO CREATE THE .exp FILE.  
*
*WHAT MUST BE DONE IN STEPS (3)-(7) MAY VARY DEPENDING ON YOUR VERSION OF 
*  MS WORD AND YOUR OPERATING SYSTEM.  THIS DESCRIPTION IS ACCURATE FOR THE
*  VERSION OF WORD IN OFFICE 2003 PROFESSIONAL, RUNNING UNDER WINDOWS XP 
*  PROFESSIONAL.
*
* (1) Open the document ('GenericIATsyntaxForm.29Dec07.doc').  
* (2) IF it does not open as a Merge document with Data Source selected, then open
*     Merge Helper by selecting Letters and Mailing in the Tools menu, and 
*     clicking Mail Merge.  This should show a MailMerge Task Pane.  Advance (at
*     bottom) to Step 3 ("Select Recipients") and select "Use an existing list".
*     "Browse" for the file 'GenericIATdata.doc' to use as the existing list.  To 
*     view contents of the data source file, you can select "Edit recipient list".
*      If you select Recipient 7, you can create a file that will analyzes the Inquisit
*      data file, "Flower-Insect Attitude.dat".
* (3) Advance to Mail Merge Step 5 ('Preview your letters').
* (4) At the File menu, click "Save As", then
* (5) Select 'Plain Text' in the "Save as type" field under the filename
* (6) Provide an appropriate file name and give it an 'sos' extension 
*     (replacing the default 'txt' extension).  Save into the same folder that 
*     contains the .dat file you wish to analyze.  If asked for File Conversion 
*     options, select the 'Windows default'.
* (7) You should then be able to run the saved .sps syntax by double-clicking its
*     filename in Windows Explorer.
*
*This syntax will work without detailed path names if SPSS is started by 
*  double-clicking this syntax (.sps) filename in order to start SPSS, *IF* this 
*  syntax file is located in the same folder containing the Inquisit data (.dat)
*  file that contains the data you wish to analyze.

** REVISION NOTES ** .
*1. First version, 26 Nov 2005.
*2. Revised 26 Aug 07 (but this revision contained errors in some variable names).
*3. Revised 29 Dec 07 to fix the errors in Revision 2.
